@@ -4,7 +4,7 @@ from singlecellexperiment import SingleCellExperiment
 import numpy as np
 from random import random
 import pandas as pd
-from genomicranges import GenomicRanges
+import genomicranges
 from singlecellexperiment.SingleCellExperiment import SingleCellExperiment as sce
 from summarizedexperiment import SummarizedExperiment
 
@@ -39,7 +39,7 @@ df_gr = pd.DataFrame(
     }
 )
 
-gr = GenomicRanges.fromPandas(df_gr)
+gr = genomicranges.fromPandas(df_gr)
 
 colData = pd.DataFrame({"treatment": ["ChIP", "Input"] * 3,})
 
